@@ -12,7 +12,8 @@ use structopt::StructOpt;
 
 use crate::api;
 use crate::k8s;
-use crate::show::Show;
+use crate::show::Detailed;
+use crate::traits::Show;
 use crate::v1;
 use crate::Location;
 use crate::Output;
@@ -115,7 +116,7 @@ enum Command {
         #[structopt(
             help = "Namespace to install statehub components",
             long,
-            default_value = "statehub"
+            default_value = "statehub-system"
         )]
         namespace: String,
 
@@ -131,6 +132,12 @@ enum Command {
         name: v1::ClusterName,
     },
 
+    #[structopt(about = "Show registered cluster details", aliases = &["show-cl", "sc"], display_order(10))]
+    ShowCluster {
+        #[structopt(help = "Cluster name")]
+        name: Option<v1::ClusterName>,
+    },
+
     #[structopt(
         about = "Manually make state available in a specified location",
         aliases = &["add-l", "al"],
@@ -196,12 +203,12 @@ enum Command {
 
     #[structopt(
         about = "Create new namespace",
-        alias = "c-ns",
+        aliases = &["cns", "c-ns", "create-ns"],
         display_order(1000),
         // setting(clap::AppSettings::Hidden)
     )]
     CreateNamespace {
-        #[structopt(help = "Namespace name")]
+        #[structopt(help = "Namespace name", default_value = "statehub-system")]
         namespace: String,
     },
 
@@ -217,12 +224,24 @@ enum Command {
         #[structopt(help = "Cluster token")]
         token: String,
     },
-    SaveConfigMap {
-        #[structopt(help = "Namespace to install statehub components")]
-        namespace: String,
+
+    #[structopt(
+        about = "Setup statehub configmap",
+        aliases = &["scm", "setup-cm"],
+        display_order(1000),
+        // setting(clap::AppSettings::Hidden)
+    )]
+    SetupConfigmap {
         #[structopt(help = "cluster name")]
         cluster: v1::ClusterName,
-        #[structopt(help = "The name of the state to configure as default storage class")]
+        #[structopt(
+            help = "Namespace to install statehub components",
+            default_value = "statehub-system"
+        )]
+        namespace: String,
+        #[structopt(
+            help = "The name of the state to configure as default storage class, nothing by default"
+        )]
         default_state: Option<String>,
     },
 
@@ -328,6 +347,14 @@ impl Cli {
             Command::UnregisterCluster { force, name } => {
                 statehub.unregister_cluster(name, force).await
             }
+            Command::ShowCluster { name } => {
+                let name = name.or_else(k8s::get_cluster_name).ok_or_else(|| {
+                    anyhow::anyhow!(
+                        "No default Kubernetes context found, need to provide cluster name"
+                    )
+                })?;
+                statehub.show_cluster(name).await
+            }
             Command::AddLocation { state, location } => {
                 statehub.add_location(state, location).await
             }
@@ -348,13 +375,13 @@ impl Cli {
             Command::SaveClusterToken { namespace, token } => {
                 statehub.save_cluster_token(namespace, token).await
             }
-            Command::SaveConfigMap {
+            Command::SetupConfigmap {
                 namespace,
                 cluster,
                 default_state,
             } => {
                 statehub
-                    .save_configmap(namespace, cluster, default_state)
+                    .setup_configmap(namespace, cluster, default_state)
                     .await
             }
             Command::ListNamespaces => statehub.list_namespaces().await,
@@ -476,6 +503,14 @@ impl StateHub {
         cluster.handle_output(self.json)
     }
 
+    async fn show_cluster(&self, name: v1::ClusterName) -> anyhow::Result<()> {
+        self.api
+            .get_cluster(&name)
+            .await
+            .map(Detailed)
+            .handle_output(self.json)
+    }
+
     async fn unregister_cluster(&self, name: v1::ClusterName, force: bool) -> anyhow::Result<()> {
         if force || self.confirm("Are you sure?") {
             log::info!("Make sure all the pods using statehub are terminated");
@@ -620,7 +655,7 @@ impl StateHub {
         Ok(())
     }
 
-    async fn save_configmap(
+    async fn setup_configmap(
         &self,
         namespace: String,
         cluster: v1::ClusterName,
@@ -686,12 +721,12 @@ trait HandleOutput {
     fn handle_output(self, json: bool) -> anyhow::Result<()>;
 }
 
-impl<T> HandleOutput for api::ApiResult<T>
+impl<T> HandleOutput for anyhow::Result<T>
 where
-    T: DeserializeOwned + Serialize + Show,
+    T: HandleOutput,
 {
     fn handle_output(self, json: bool) -> anyhow::Result<()> {
-        self.and_then(|output| output.handle_output(json))
+        self?.handle_output(json)
     }
 }
 
@@ -704,3 +739,13 @@ where
         Ok(())
     }
 }
+
+impl<T> HandleOutput for Detailed<Output<T>>
+where
+    T: DeserializeOwned + Serialize + Show,
+{
+    fn handle_output(self, json: bool) -> anyhow::Result<()> {
+        println!("{}", self.into_text(json));
+        Ok(())
+    }
+}
